# Generated by Django 3.1.5 on 2021-03-24 15:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0006_auto_20210324_1219'),
    ]

    operations = [
        migrations.AlterField(
            model_name='persona',
            name='tipo_doc',
            field=models.SmallIntegerField(blank=True, choices=[(0, 'DNI'), (1, 'LC'), (2, 'LE'), (3, 'Otro'), (4, 'Extranjero')], default=None, null=True, verbose_name='tipo documento'),
        ),
    ]
