# Generated by Django 3.1.5 on 2021-03-24 21:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0007_auto_20210324_1222'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='persona',
            name='celular',
        ),
        migrations.RemoveField(
            model_name='profesional',
            name='celular',
        ),
        migrations.AlterField(
            model_name='catastro',
            name='poligono',
            field=models.CharField(blank=True, max_length=10, verbose_name='polígono'),
        ),
        migrations.AlterField(
            model_name='catastro',
            name='seccion',
            field=models.CharField(blank=True, max_length=10, verbose_name='sección'),
        ),
        migrations.AlterField(
            model_name='catastrolocal',
            name='poligono',
            field=models.CharField(blank=True, max_length=20, verbose_name='polígono'),
        ),
        migrations.AlterField(
            model_name='catastrolocal',
            name='seccion',
            field=models.CharField(blank=True, max_length=20, verbose_name='sección'),
        ),
        migrations.AlterField(
            model_name='expediente',
            name='id',
            field=models.IntegerField(primary_key=True, serialize=False, verbose_name='Expediente'),
        ),
        migrations.AlterField(
            model_name='persona',
            name='telefono',
            field=models.CharField(blank=True, max_length=15, verbose_name='teléfono'),
        ),
        migrations.AlterField(
            model_name='profesional',
            name='telefono',
            field=models.CharField(blank=True, max_length=15, verbose_name='teléfono'),
        ),
        migrations.AlterField(
            model_name='profesional',
            name='titulo',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.titulo'),
        ),
    ]
