<!doctype html>
<html lang="es">

<head>
  {% load static %}
  <!-- Required meta tags -->
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
  <title>GEA | {% block title %}Base{% endblock title %}</title>

  {% block css %}
  <!-- Bootstrap CSS -->
  <link href="{% static 'css/bootstrap.min.css' %}" rel="stylesheet">

  <!-- Fontawesome CDN -->
  <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.6.3/css/all.css"
    integrity="sha384-UHRtZLI+pbxtHCWp1t77Bi1L4ZtiqrqD80Kn4Z8NTSRyMA2Fd33n5dQ8lWUE00s/" crossorigin="anonymous">
  {% endblock css %}
  {% block extra_css %}{% endblock extra_css %}

  {% block font %}
  <link href="https://fonts.googleapis.com/css?family=Raleway" rel="stylesheet">
  {% endblock font %}

  <!-- Description & Author -->
  <meta name="description" content="Gesti&oacute;n de Expedientes de Agrimensores">
  <meta name="author" content="GEAdevel">

  <!-- Icon -->
  <link rel="shortcut icon" href="{% static 'img/folder-o.png' %}">

</head>

<body id="page-top">
  {% block body %}
  <!-- Page Wrapper -->
  <div id="wrapper">
    <!-- Content Wrapper -->
    <div id="content-wrapper" class="d-flex flex-column">
      <!-- Main Content -->
      <div id="content">
        {% block topbar %}{% include 'includes/topbar.html' %}{% endblock %}
        <!-- Begin Page Content -->
        <div class="container">
          {% block messages %}
          <!-- Messages -->
          {% if messages %}
          {% for message in messages %}
          <div class="row justify-content-end mt-3" id="messages">
            <div class="col-lg-6 col-sm-12">
              <div
                class="alert{% if message.tags == 'error' %} alert-danger {% elif message.tags %} alert-{{ message.tags }} {% else %} alert-primary {% endif %} alert-dismissible fade show"
                role="alert">
                {% if message.level == DEFAULT_MESSAGE_LEVELS.ERROR %}<strong>ERROR</strong>:{% endif %}
                {{ message|safe }}
                <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                  <span aria-hidden="true">&times;</span>
                </button>
              </div>
            </div>
          </div>
          {% endfor %}
          {% endif %}
          {% endblock messages %}
          <!-- Page Heading -->
          {% block page-heading %}
          <div class="d-sm-flex align-items-center justify-content-between my-4">
            <h1 class="mb-2">{% block page-title %}{% endblock page-title %}</h1>
            {% block page-heading-buttons %}
            <!-- Button Group sample
            <div class="btn-group d-print-none" role="group" aria-label="Actions">
              <a href="#" class="d-sm-inline-block btn btn-sm btn-primary shadow-sm">
                <i class="fas fa-plus fa-sm text-white-50"></i>
                Agregar
              </a>
            </div>
            -->
            {% endblock page-heading-buttons %}
          </div>
          {% endblock page-heading %}
          {% block content %}{% endblock content %}
        </div>
        <!-- /.container-fluid -->
      </div>
      <!-- End of Main Content -->
      {% block footer %}
      <!-- Footer -->
      <footer id="footer" class="sticky-footer">
        <div class="container my-auto">
          <!-- Copyright -->
          <div class="copyright text-center my-auto">
            <small class="text-muted">
              <strong>GEA</strong> &copy; {% now "Y" %}. Todos los derechos reservados.
              <a class="text-dark" href="#">GEAdevel</a>
            </small>
          </div>
        </div>
      </footer>
      {% endblock footer %}
    </div>
    <!-- End of Content Wrapper -->
  </div>
  <!-- End of Page Wrapper -->
  {% block top-button %}
  <!-- Scroll to Top Button-->
  <div class="d-flex justify-content-end">
    <a class="btn btn-outline-primary d-print-none m-3" href="#page-top">
      <i class="fas fa-angle-up"></i>
    </a>
  </div>
  {% endblock top-button %}

  {% block js %}
  <!-- jQuery and Bootstrap Bundle (includes Popper) -->
  <!-- <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"
    integrity="sha384-DfXdz2htPH0lsSSs5nCTpuj/zy4C+OGpamoFVy38MVBnE+IbbVYUew+OrCXaRkfj"
    crossorigin="anonymous"></script> -->
  <script src="https://code.jquery.com/jquery-3.6.0.min.js"
    integrity="sha256-/xUj+3OJU5yExlq6GSYGSHk7tPXikynS7ogEvDej/m4=" crossorigin="anonymous"></script>
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"
    integrity="sha384-Piv4xVNRyMGpqkS2by6br4gNJ7DXjqk09RmUpJ8jgGtD7zP9yug3goQfGII0yAns"
    crossorigin="anonymous"></script>

  <!-- Messages Fade  -->
  <script>
    $(document).ready(function () {
      $("#messages").fadeTo(5000, 0.9).slideUp();
    });
  </script>
  {% endblock js %}
  {% block extra_js %}{% endblock extra_js %}
  {% endblock body %}
</body>

</html>