{% extends "base.html" %}
{% block title %}Catastos Locales{% endblock title %}

{% block page-title %}
<i class="fas fa-fw fa-map-signs"></i>
Catastros Locales
{% if lugar %}
<span class="h5 ml-3">
  {{ lugar }}
  - sección:<strong>{{ seccion|default:"todas" }}</strong>
  - manzana:<strong>{{ manzana|default:"todas" }}</strong>
  - parcela:<strong>{{ parcela|default:"todas" }}</strong>
</span>
{% endif %}
{% endblock %}

{% load tags %}
{% block content %}

<!-- Filtros -->
<div class="card bg-light shadow mb-2">
  <div class="card-body">
    <div class="row">
      <div class="col-lg-1">Lugar</div>
      <div class="dropdown col-lg-4">
        <button class="btn btn-sm btn-outline-secondary dropdown-toggle" type="button" id="lugar" name="lugar"
          data-toggle="dropdown" aria-haspopup="true" aria-expanded="true">
          <strong>{{ lugar|default:"Seleccione un Lugar" }}</strong>
        </button>
        <div class="dropdown-menu">
          {% for l in lugares %}
          <a class="dropdown-item {% if lugar == l %}active{% endif %}"
            href="{% url 'catastros_locales' %}?lugar={{ l }}">
            <small>{{ l }}</small>
          </a>
          {% endfor %}
        </div>
      </div>
      <div class="col-lg-1">Sección</div>
      <div class="col-lg-6 btn-group btn-group-sm" role="group">
        <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}"
          class="btn {% if not seccion %}btn-outline-secondary active{% else %} btn-info{% endif %}">*</a>
        {% for s in secciones %}
        <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}&seccion={{ s }}"
          class="btn {% if seccion == s %}btn-outline-secondary active{% else %} btn-primary{% endif %}">{{ s }}</a>
        {% endfor %}
      </div>
    </div>
    <div class="row">
      <div class="col-lg-1">Manzana</div>
      <div class="col-lg-11 btn-group btn-group-sm" role="group">
        <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}"
          class="btn {% if not manzana %}btn-outline-secondary active{% else %} btn-info{% endif %}">*</a>
        {% for m in manzanas %}
        <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}{% if seccion %}&seccion={{ seccion }}{% endif %}&manzana={{ m }}"
          class="btn {% if manzana == m %}btn-outline-secondary active{% else %} btn-primary{% endif %}">{{ m }}</a>
        {% endfor %}
      </div>
    </div>
    <div class="row">
      <div class="col-lg-1">Parcela</div>
      <div class="col-lg-11 btn-group btn-group-sm" role="group">
        <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}&seccion={{ seccion }}&manzana={{ manzana }}"
          class="btn {% if not parcela %}btn-outline-secondary active{% else %} btn-info{% endif %}">*</a>
        {% for p in parcelas %}
        <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}&seccion={{ seccion }}&manzana={{ manzana }}&parcela={{ p }}"
          class="btn {% if parcela == p %}btn-outline-secondary active{% else %} btn-primary{% endif %}">{{ p }}</a>
        {% endfor %}
      </div>
    </div>
  </div>
</div>

<!-- Data -->
<div class="card bg-light shadow mb-2">
  <div class="card-body">
    <div class="row">
      <!-- Filter -->
      <div class="col-sm-12 col-md-4">
        <div class="d-flex justify-content-start align-items-start">
          <label>
            Mostrando
            <strong>{{ object_list.count }}</strong>
            de
            <strong>{{ count }}</strong>
            registro{% if count > 1 %}s{% endif %}
          </label>
        </div>
      </div>
      <div class="col-sm-12 col-md-8">
        <div class="d-flex justify-content-end align-items-start">
          {% include "includes/_pagination.html" %}
        </div>
      </div>
    </div>
    <div class="row">
      <!-- Data -->
      <div class="col-sm-12">
        <table class="table table-sm table-striped table-hover table-bordered">
          <thead>
            <tr>
              <th>Expediente</th>
              <th>Persona(s)</th>
              <th>Lugar(es)</th>
              <th>Partida(s)</th>
              <th>Plano</th>
            </tr>
          </thead>
          <tbody>
            {% for e in object_list %}
            <tr>
              <td>
                <!-- EXPEDIENTE -->
                <a href="/admin/gea/expediente/{{ e.id }}/">{{ e.id }}</a>
                <!--<a href="{% url 'expediente' e.id %}">{{ e.id }}</a>-->
              </td>
              <td>
                <!-- PERSONAS -->
                {% if e.orden_numero and not e.inscripcion_numero %}
                <span class="badge badge-warning">PENDIENTE</span>
                Orden N&ordm; {{ e.orden_numero }} - {{ e.orden_fecha }}<br>
                {% endif %}
                {% if e.cancelado %}
                <span class="badge badge-danger">CANCELADO</span>
                {{ e.cancelado_por }}<br>
                {% endif %}
                {% if e.expedientepersona_set %}
                {% for ep in e.expedientepersona_set.all %}
                <a href="/admin/gea/persona/{{ ep.persona.id }}/">{{ ep.persona.nombre_completo }}</a>
                {% if ep.comitente %}<span class="badge badge-primary">COMITENTE</span>{% endif %}
                {% if ep.persona.telefono %}({{ ep.persona.telefono }}){% endif %}
                {% if not forloop.last %}<br>{% endif %}
                {% endfor %}
                {% endif %}
              </td>
              <td>
                <!-- LUGARES -->
                {% if e.expedientelugar_set %}
                {% for el in e.expedientelugar_set.all %}
                <a href="/admin/gea/lugar/{{ el.lugar.id }}/">{{ el.lugar.nombre }}</a>
                {% for cl in el.catastrolocal_set.all %}<br>
                {{ cl }}
                {% endfor %}
                {% if not forloop.last %}<br>{% endif %}
                {% endfor %}
                {% endif %}
              </td>
              <td>
                <!-- PARTIDAS -->
                {% if e.expedientepartida_set %}
                {% for ep in e.expedientepartida_set.all %}
                {% if ep.set_ruta %}<a href="{{ ep.set_ruta }}">{% endif %}
                  {{ ep.partida.sd }}-{{ ep.partida }}
                  {% if ep.set_ruta %}</a>{% endif %}
                {% if not forloop.last %}<br>{% endif %}
                {% endfor %}
                {% endif %}
              </td>
              <td>
                <!-- PLANO -->
                {% if e.plano_ruta %}<a href="{{ e.plano_ruta }}">{% endif %}
                  {% if e.duplicado %}Dup.{% endif %}{% if e.inscripcion_numero %}{{ e.inscripcion_numero }}{% endif %}
                  {% if e.plano_ruta %}</a>{% endif %}
                {% if e.inscripcion_fecha %}({{ e.inscripcion_fecha }}){% endif %}
                {% if e.sin_inscripcion %}<span class="badge badge-info">NO REQUIERE</span>{% endif %}
              </td>
            </tr>
            {% empty %}
            <div class="alert alert-info" role="alert">
              <i class="fas fa-fw fa-info-circle" aria-hidden="true"></i>
              <span class="sr-only">Información:</span>
              No se encontraron Expedientes.
            </div>
            {% endfor %}
          </tbody>
        </table>
      </div>
    </div>
  </div>
</div>

{% endblock content %}